diff mbox series

[v2,7/9] ttm: Call shmem_writeout() from ttm_backup_backup_page()

Message ID 20250402150005.2309458-8-willy@infradead.org (mailing list archive)
State New
Headers show
Series Remove aops->writepage | expand

Commit Message

Matthew Wilcox April 2, 2025, 3 p.m. UTC
The ->writepage operation is being removed.  Since this function
exclusively deals with shmem folios, we can call shmem_writeout()
to write it.

Signed-off-by: Matthew Wilcox (Oracle) <willy@infradead.org>
---
 drivers/gpu/drm/ttm/ttm_backup.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
diff mbox series

Patch

diff --git a/drivers/gpu/drm/ttm/ttm_backup.c b/drivers/gpu/drm/ttm/ttm_backup.c
index 93c007f18855..0d5718466ffc 100644
--- a/drivers/gpu/drm/ttm/ttm_backup.c
+++ b/drivers/gpu/drm/ttm/ttm_backup.c
@@ -136,13 +136,13 @@  ttm_backup_backup_page(struct ttm_backup *backup, struct page *page,
 			.for_reclaim = 1,
 		};
 		folio_set_reclaim(to_folio);
-		ret = mapping->a_ops->writepage(folio_file_page(to_folio, idx), &wbc);
+		ret = shmem_writeout(to_folio, &wbc);
 		if (!folio_test_writeback(to_folio))
 			folio_clear_reclaim(to_folio);
 		/*
 		 * If writepage succeeds, it unlocks the folio.
 		 * writepage() errors are otherwise dropped, since writepage()
 		 * is only best effort here.
 		 */
 		if (ret)
 			folio_unlock(to_folio);
@@ -136,13 +136,13 @@  ttm_backup_backup_page(struct ttm_backup *backup, struct page *page,
 			folio_clear_reclaim(to_folio);
 		/*
-		 * If writepage succeeds, it unlocks the folio.
-		 * writepage() errors are otherwise dropped, since writepage()
-		 * is only best effort here.
+		 * If writeout succeeds, it unlocks the folio.	errors
+		 * are otherwise dropped, since writeout is only best
+		 * effort here.
 		 */
 		if (ret)